@@ -57,19 +57,28 @@ get_group_names.multinom <- function(model, ...) {
 #' @export
 get_predict.multinom <- function(model,
                                  newdata = insight::get_data(model),
-                                 type = "response",
-                                 group_name = "1",
+                                 type = "probs",
                                  ...) {
+
+    type <- sanity_type(model, type)
+
+    # needed because `predict.multinom` uses `data` rather than `newdata`
     pred <- stats::predict(model,
                            newdata = newdata,
-                           type = type)
-    sanity_predict_numeric(pred = pred, model = model, newdata = newdata, type = type)
-    # numDeriv expects a vector
-    if (is.matrix(pred) && (!is.null(group_name) && group_name != "main_marginaleffect")) {
-        pred <- pred[, group_name, drop = TRUE]
-    # predict() returns a vector if there is just one row in `newdata`
-    } else if (nrow(newdata) == 1) {
-        pred <- pred[group_name]
+                           type = type,
+                           ...)
+
+    # atomic vector means there is only one row in `newdata`
+    if (isTRUE(checkmate::check_atomic_vector(pred))) {
+        pred <- matrix(pred, nrow = 1, dimnames = list(NULL, names(pred)))
     }
-    return(pred)
+
+    # matrix with outcome levels as columns
+    out <- data.frame(
+        rowid = rep(1:nrow(pred), times = ncol(pred)),
+        group = rep(colnames(pred), each = nrow(pred)),
+        predicted = c(pred))
+
+    return(out)
 }
+
