@@ -20,6 +20,7 @@ sanity_model_supported_class <- function(model) {
                       "bife",
                       "brglmFit",
                       "brmsfit",
+                      c("bracl", "brmultinom", "brglmFit"),
                       c("brnb", "negbin", "glm"),
                       "clm",
                       "coxph",
@@ -41,16 +42,19 @@ sanity_model_supported_class <- function(model) {
                       "iv_robust",
                       "lm",
                       "lmerMod",
+                      "lmerModLmerTest",
                       "lmrob",
                       "lm_robust",
                       "loess",
                       c("lrm", "lm"),
                       c("lrm", "rms", "glm"),
+                      c("mblogit", "mclogit"),
                       c("multinom", "nnet"),
                       c("negbin", "glm", "lm"),
                       c("plm", "panelmodel"),
                       "polr",
                       "rq",
+                      c("scam", "glm", "lm"),
                       "speedglm",
                       "speedlm",
                       "stanreg",
@@ -70,7 +74,7 @@ sanity_model_supported_class <- function(model) {
 
 Supported model classes include: %s. 
  
-New modeling packages can usually be supported by `marginaleffects` if they include a working `predict` method. If you believe that this is the case, please file a feature request on Github: https://github.com/vincentarelbundock/marginaleffects/issues' 
+New modeling packages can usually be supported by `marginaleffects` if they include a working `predict()` method. If you believe that this is the case, please file a feature request on Github: https://github.com/vincentarelbundock/marginaleffects/issues' 
         msg <- sprintf(msg, class(model)[1], support)
         stop(msg)
     }
