@@ -1,5 +1,5 @@
-skip_if_not_installed("plm")
 requiet("plm")
+requiet("margins")
 
 data("Grunfeld", package = "plm")
 
@@ -27,6 +27,11 @@ test_that("Swamy-Arora vs. Stata", {
     expect_marginaleffects(mod)
     expect_equal(mfx$estimate, mfx$dydxstata)
     expect_equal(mfx$std.error, mfx$std.errorstata, tolerance = .0001)
+    # margins
+    mfx <- tidy(marginaleffects(mod))
+    mar <- tidy(margins(mod))
+    expect_equal(mfx$estimate, mar$estimate, ignore_attr = TRUE)
+    expect_equal(mfx$std.error, mar$std.error, ignore_attr = TRUE, tolerance = .0001)
 })
 
 
@@ -35,10 +40,24 @@ test_that("no validity checks", {
                    data = Grunfeld, model = "random", random.method = "amemiya",
                    effect = "twoways")
     expect_marginaleffects(amemiya)
+
+    # margins
+    mfx <- tidy(marginaleffects(amemiya))
+    mar <- tidy(margins(amemiya))
+    expect_equal(mfx$estimate, mar$estimate, ignore_attr = TRUE)
+    expect_equal(mfx$std.error, mar$std.error, ignore_attr = TRUE, tolerance = .001)
+
+
     walhus <- plm(inv ~ value * capital,
                   data = Grunfeld, model = "random", random.method = "walhus",
                   effect = "twoways")
     expect_marginaleffects(walhus)
+
+    # margins
+    mfx <- tidy(marginaleffects(walhus))
+    mar <- tidy(margins(walhus))
+    expect_equal(mfx$estimate, mar$estimate, ignore_attr = TRUE)
+    expect_equal(mfx$std.error, mar$std.error, ignore_attr = TRUE, tolerance = .001)
 })
 
 
@@ -56,6 +75,6 @@ test_that("predictions: pooling no validity", {
     pool <- plm(inv ~ value * capital, data = Grunfeld, model = "pooling")
     pred1 <- predictions(pool)
     pred2 <- predictions(pool, newdata = head(Grunfeld))
-    expect_predictions(pred1, n_row = 1, se = FALSE)
-    expect_predictions(pred2, n_row = 6, se = FALSE)
+    expect_predictions(pred1, n_row = nrow(Grunfeld))
+    expect_predictions(pred2, n_row = 6)
 })
